@@ -20,17 +20,17 @@ def stack_template() -> Template:
 
 # pylint: disable=redefined-outer-name
 def test_application_load_balancer(stack_template):
-    """Test if CodeCommit repository created."""
+    """Test if EC2 Application Load Balancer is created."""
     stack_template.resource_count_is("AWS::ElasticLoadBalancingV2::LoadBalancer", 1)
 
 
 # pylint: disable=redefined-outer-name
 def test_kms_key(stack_template):
-    """Test if KMS key created."""
+    """Test if KMS key is created."""
     stack_template.resource_count_is("AWS::KMS::Key", 1)
 
 
 # pylint: disable=redefined-outer-name
 def test_access_logs_bucket(stack_template):
-    """Test if SNS topic created."""
+    """Test if S3 bucket is created."""
     stack_template.resource_count_is("AWS::S3::Bucket", 1)
